16.58. cdist-type__group(7) — cdist 6.9.4 documentation

# 16.58. cdist-type__group(7)

## 16.58.1. NAME

cdist-type__group - Manage groups

## 16.58.2. DESCRIPTION

This cdist type allows you to create or modify groups on the target.

## 16.58.3. REQUIRED PARAMETERS

None.

## 16.58.4. OPTIONAL PARAMETERS

state

  absent or present, defaults to present

gid

  see groupmod(8)

password

  see above

## 16.58.5. BOOLEAN PARAMETERS

system

  see groupadd(8), apply only on group creation

## 16.58.6. MESSAGES

mod

  group is modified

add

  New group added

remove

  group is removed

change <property> <new_value> <current_value>

  Changed group property from current_value to new_value

set <property> <new_value>

  set property to new value, property was not set before

## 16.58.7. EXAMPLES

    # Create a group 'foobar' with operating system default settings
    __group foobar

    # Remove the 'foobar' group
    __group foobar --state absent

    # Create a system group 'myservice' with operating system default settings
    __group myservice --system

    # Same but with a specific gid
    __group foobar --gid 1234

    # Same but with a gid and password
    __group foobar --gid 1234 --password 'crypted-password-string'

## 16.58.8. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.58.9. COPYING

Copyright (C) 2011-2015 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.